:orphan:

`plasmapy.dispersion.analytical`
================================

.. currentmodule:: plasmapy.dispersion.analytical

.. automodapi:: plasmapy.dispersion.analytical

Example Notebooks
-----------------

.. nbgallery::

    /notebooks/dispersion/two_fluid_dispersion
    /notebooks/dispersion/stix_dispersion
